/*

  $Id: atsoer.h,v 1.2 2004/07/03 22:56:52 pkot Exp $

  G N O K I I

  A Linux/Unix toolset and driver for mobile phones.

  This file is part of gnokii.

  Gnokii is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  Gnokii is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with gnokii; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  Copyright 2004 Pawel Kot <pkot@bezsensu.pl>

  This file provides functions specific to AT commands on SonyEricsson phones.
  See README for more details on supported mobile phones.

*/

#ifndef _gnokii_atsoer_h
#define _gnokii_atsoer_h

#include "gnokii-internal.h"

void at_sonyericsson_init(char* foundmodel, char* setupmodel, struct gn_statemachine *state);

#endif
